@@ -1,22 +1,24 @@
-from bionumpy.sequences import EncodedArray, as_encoded_sequence_array, Sequences
+from .encoded_array import EncodedArray, as_encoded_array, EncodedRaggedArray
+from .lookup import Lookup
 
 
 def _get_complement_lookup(alphabet_encoding):
     alphabet = alphabet_encoding.get_alphabet()
-    complements = {"a": "t", "g": "c", "c": "g", "t": "a"}
+    complements = {"A": "T", "G": "C", "C": "G", "T": "A"}
     new_alphabet = "".join(complements[c] for c in alphabet)
-    return as_encoded_sequence_array(new_alphabet, alphabet_encoding)
+    return Lookup(as_encoded_array(new_alphabet, alphabet_encoding),
+                  alphabet_encoding)
 
 
 def complement(_array):
     array = _array
-    if isinstance(_array, Sequences):
+    if isinstance(_array, EncodedRaggedArray):
         array, _array.ravel()
     assert isinstance(array, EncodedArray)
     lookup = _get_complement_lookup(array.encoding)
     new_data = lookup[array]
-    if isinstance(_array, Sequences):
-        new_data = Sequences(new_data, _array.shape)
+    if isinstance(_array, EncodedRaggedArray):
+        new_data = EncodedRaggedArray(new_data, _array.shape)
     return new_data
 
 
