@@ -20,6 +20,12 @@ class ASCIIEncoding(Encoding):
     def decode(self, encoded):
         return encoded
 
+    def __repr__(self):
+        return "ASCIIEncoding()"
+
+    def __hash__(self):
+        return hash(repr(self))
+
 
 class NumericEncoding(Encoding):
     pass
@@ -36,3 +42,7 @@ class CigarEncoding(NumericEncoding):
 
 
 BaseEncoding = ASCIIEncoding()
+
+
+def get_base_encodings():
+    return [BaseEncoding]  # TODO: add other encodings
