@@ -1,6 +1,6 @@
 from .kmers import KmerEncoding
 from .rollable import RollableFunction
-from .encodings import ACTGEncoding
+from .encodings import DNAEncoding
 
 
 class Minimizers(RollableFunction):
