@@ -1,5 +1,6 @@
 import pytest
-from bionumpy.encoded_array import EncodedArray, EncodedRaggedArray
+from bionumpy.encoded_array import EncodedArray, EncodedRaggedArray, as_encoded_array
+from bionumpy.testing import assert_encoded_raggedarray_equal
 import bionumpy as bnp
 import numpy as np
 
@@ -39,5 +40,22 @@ def test_works_with_ragged():
     ragged = EncodedRaggedArray(encoded_array, [2, 1])
 
 
+def test_empty_encoded():
+    result = as_encoded_array(['', ''])
+    true = EncodedRaggedArray(EncodedArray(np.empty((0,), dtype=np.uint8)),
+                              [0, 0])
+                                           
+    assert_encoded_raggedarray_equal(result, true)
+
+
+def test_empty_dna_encoded():
+    result = as_encoded_array(['', ''], bnp.DNAEncoding)
+    true = EncodedRaggedArray(EncodedArray(np.empty((0,), dtype=np.uint8), bnp.DNAEncoding),
+                              [0, 0])
+                                           
+    assert_encoded_raggedarray_equal(result, true)
+    
+
+
 if __name__ == "__main__":
     test_works_with_ragged()
