@@ -1,6 +1,7 @@
 import re
 
 from npstructures import RaggedArray
+from npstructures.testing import assert_raggedarray_equal
 from bionumpy.string_matcher import RegexMatcher, FixedLenRegexMatcher, StringMatcher
 import bionumpy as bnp
 
@@ -8,9 +9,9 @@ import bionumpy as bnp
 def test_plain_string_matching():
     # Would probably reuse code for checking matches, but have different given, and different matcher class
     matcher = StringMatcher('V1-1', encoding=bnp.encodings.BaseEncoding)
-    seq_array = bnp.as_encoded_sequence_array(['V1-1', 'V2-1', 'V1-1*2'], encoding=bnp.encodings.BaseEncoding)
+    seq_array = bnp.as_encoded_array(['V1-1', 'V2-1', 'V1-1*2'])
     matches = matcher.rolling_window(seq_array)
-    assert matches == RaggedArray([[True], [False], [True, False, False]])
+    assert_raggedarray_equal(matches, RaggedArray([[True], [False], [True, False, False]]))
 
 
 def test_fixedlen_regex_matching():
@@ -27,10 +28,10 @@ def test_fixedlen_regex_matching():
                    for offset in range(len(seq) - pattern_len + 1)]
                   for seq in sequences]
 
-    sequence_array = bnp.as_encoded_sequence_array(sequences, encoding=bnp.encodings.ACTGEncoding)
-    matcher = FixedLenRegexMatcher(pattern, encoding=bnp.encodings.ACTGEncoding)
+    sequence_array = bnp.as_encoded_array(sequences, target_encoding=bnp.encodings.DNAEncoding)
+    matcher = FixedLenRegexMatcher(pattern, encoding=bnp.encodings.DNAEncoding)
     matches = matcher.rolling_window(sequence_array)
-    assert matches == RaggedArray(re_matches)  # TODO: switch to correct assertion..
+    assert_raggedarray_equal(matches, RaggedArray(re_matches))  # TODO: switch to correct assertion..
 
 
 def test_flexible_len_regex_matching():
@@ -40,7 +41,7 @@ def test_flexible_len_regex_matching():
     re_matches = [[False for _ in range(7)],
                   [True, False, False, False, True, True, False, False]]
 
-    sequence_array = bnp.as_encoded_sequence_array(sequences, encoding=bnp.encodings.ACTGEncoding)
-    matcher = RegexMatcher(pattern, encoding=bnp.encodings.ACTGEncoding)
+    sequence_array = bnp.as_encoded_array(sequences, target_encoding=bnp.encodings.DNAEncoding)
+    matcher = RegexMatcher(pattern, encoding=bnp.encodings.DNAEncoding)
     matches = matcher.rolling_window(sequence_array)
-    assert matches == RaggedArray(re_matches)  # TODO: switch to correct assertion..
+    assert_raggedarray_equal(matches, RaggedArray(re_matches))  # TODO: switch to correct assertion..
